from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import AuthenticationV1TokenRequest
from kubernetes_asyncio.client.models import CoreV1Event
from kubernetes_asyncio.client.models import CoreV1EventList
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1Binding
from kubernetes_asyncio.client.models import V1ComponentStatus
from kubernetes_asyncio.client.models import V1ComponentStatusList
from kubernetes_asyncio.client.models import V1ConfigMap
from kubernetes_asyncio.client.models import V1ConfigMapList
from kubernetes_asyncio.client.models import V1Endpoints
from kubernetes_asyncio.client.models import V1EndpointsList
from kubernetes_asyncio.client.models import V1Eviction
from kubernetes_asyncio.client.models import V1LimitRange
from kubernetes_asyncio.client.models import V1LimitRangeList
from kubernetes_asyncio.client.models import V1Namespace
from kubernetes_asyncio.client.models import V1NamespaceList
from kubernetes_asyncio.client.models import V1Node
from kubernetes_asyncio.client.models import V1NodeList
from kubernetes_asyncio.client.models import V1PersistentVolume
from kubernetes_asyncio.client.models import V1PersistentVolumeClaim
from kubernetes_asyncio.client.models import V1PersistentVolumeClaimList
from kubernetes_asyncio.client.models import V1PersistentVolumeList
from kubernetes_asyncio.client.models import V1Pod
from kubernetes_asyncio.client.models import V1PodList
from kubernetes_asyncio.client.models import V1PodTemplate
from kubernetes_asyncio.client.models import V1PodTemplateList
from kubernetes_asyncio.client.models import V1ReplicationController
from kubernetes_asyncio.client.models import V1ReplicationControllerList
from kubernetes_asyncio.client.models import V1ResourceQuota
from kubernetes_asyncio.client.models import V1ResourceQuotaList
from kubernetes_asyncio.client.models import V1Scale
from kubernetes_asyncio.client.models import V1Secret
from kubernetes_asyncio.client.models import V1SecretList
from kubernetes_asyncio.client.models import V1Service
from kubernetes_asyncio.client.models import V1ServiceAccount
from kubernetes_asyncio.client.models import V1ServiceAccountList
from kubernetes_asyncio.client.models import V1ServiceList
from kubernetes_asyncio.client.models import V1Status
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class CoreV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def connect_delete_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_delete_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_delete_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_delete_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_delete_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_delete_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_delete_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_pod_attach(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_pod_attach_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_pod_exec(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_pod_exec_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_pod_portforward(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_pod_portforward_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_get_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_get_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_head_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_head_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_options_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_options_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_patch_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_patch_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_pod_attach(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_pod_attach_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_pod_exec(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_pod_exec_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_pod_portforward(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_pod_portforward_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_post_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_post_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_namespaced_pod_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_namespaced_pod_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_namespaced_pod_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_namespaced_pod_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_namespaced_service_proxy(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_namespaced_service_proxy_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_namespaced_service_proxy_with_path(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_namespaced_service_proxy_with_path_with_http_info(self, name: str, namespace: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_node_proxy(self, name: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_node_proxy_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def connect_put_node_proxy_with_path(self, name: str, path: str, **kwargs: Any) -> Awaitable[str]: ...
    def connect_put_node_proxy_with_path_with_http_info(self, name: str, path: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def create_namespace(self, body: V1Namespace, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def create_namespace_with_http_info(self, body: V1Namespace, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def create_namespaced_binding(self, namespace: str, body: V1Binding, **kwargs: Any) -> Awaitable[V1Binding]: ...
    def create_namespaced_binding_with_http_info(self, namespace: str, body: V1Binding, **kwargs: Any) -> Awaitable[tuple[V1Binding, int, CIMultiDictProxy]]: ...
    def create_namespaced_config_map(self, namespace: str, body: V1ConfigMap, **kwargs: Any) -> Awaitable[V1ConfigMap]: ...
    def create_namespaced_config_map_with_http_info(self, namespace: str, body: V1ConfigMap, **kwargs: Any) -> Awaitable[tuple[V1ConfigMap, int, CIMultiDictProxy]]: ...
    def create_namespaced_endpoints(self, namespace: str, body: V1Endpoints, **kwargs: Any) -> Awaitable[V1Endpoints]: ...
    def create_namespaced_endpoints_with_http_info(self, namespace: str, body: V1Endpoints, **kwargs: Any) -> Awaitable[tuple[V1Endpoints, int, CIMultiDictProxy]]: ...
    def create_namespaced_event(self, namespace: str, body: CoreV1Event, **kwargs: Any) -> Awaitable[CoreV1Event]: ...
    def create_namespaced_event_with_http_info(self, namespace: str, body: CoreV1Event, **kwargs: Any) -> Awaitable[tuple[CoreV1Event, int, CIMultiDictProxy]]: ...
    def create_namespaced_limit_range(self, namespace: str, body: V1LimitRange, **kwargs: Any) -> Awaitable[V1LimitRange]: ...
    def create_namespaced_limit_range_with_http_info(self, namespace: str, body: V1LimitRange, **kwargs: Any) -> Awaitable[tuple[V1LimitRange, int, CIMultiDictProxy]]: ...
    def create_namespaced_persistent_volume_claim(self, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def create_namespaced_persistent_volume_claim_with_http_info(self, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def create_namespaced_pod(self, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def create_namespaced_pod_binding(self, name: str, namespace: str, body: V1Binding, **kwargs: Any) -> Awaitable[V1Binding]: ...
    def create_namespaced_pod_binding_with_http_info(self, name: str, namespace: str, body: V1Binding, **kwargs: Any) -> Awaitable[tuple[V1Binding, int, CIMultiDictProxy]]: ...
    def create_namespaced_pod_eviction(self, name: str, namespace: str, body: V1Eviction, **kwargs: Any) -> Awaitable[V1Eviction]: ...
    def create_namespaced_pod_eviction_with_http_info(self, name: str, namespace: str, body: V1Eviction, **kwargs: Any) -> Awaitable[tuple[V1Eviction, int, CIMultiDictProxy]]: ...
    def create_namespaced_pod_template(self, namespace: str, body: V1PodTemplate, **kwargs: Any) -> Awaitable[V1PodTemplate]: ...
    def create_namespaced_pod_template_with_http_info(self, namespace: str, body: V1PodTemplate, **kwargs: Any) -> Awaitable[tuple[V1PodTemplate, int, CIMultiDictProxy]]: ...
    def create_namespaced_pod_with_http_info(self, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def create_namespaced_replication_controller(self, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def create_namespaced_replication_controller_with_http_info(self, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def create_namespaced_resource_quota(self, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def create_namespaced_resource_quota_with_http_info(self, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def create_namespaced_secret(self, namespace: str, body: V1Secret, **kwargs: Any) -> Awaitable[V1Secret]: ...
    def create_namespaced_secret_with_http_info(self, namespace: str, body: V1Secret, **kwargs: Any) -> Awaitable[tuple[V1Secret, int, CIMultiDictProxy]]: ...
    def create_namespaced_service(self, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[V1Service]: ...
    def create_namespaced_service_account(self, namespace: str, body: V1ServiceAccount, **kwargs: Any) -> Awaitable[V1ServiceAccount]: ...
    def create_namespaced_service_account_token(self, name: str, namespace: str, body: AuthenticationV1TokenRequest, **kwargs: Any) -> Awaitable[AuthenticationV1TokenRequest]: ...
    def create_namespaced_service_account_token_with_http_info(self, name: str, namespace: str, body: AuthenticationV1TokenRequest, **kwargs: Any) -> Awaitable[tuple[AuthenticationV1TokenRequest, int, CIMultiDictProxy]]: ...
    def create_namespaced_service_account_with_http_info(self, namespace: str, body: V1ServiceAccount, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccount, int, CIMultiDictProxy]]: ...
    def create_namespaced_service_with_http_info(self, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def create_node(self, body: V1Node, **kwargs: Any) -> Awaitable[V1Node]: ...
    def create_node_with_http_info(self, body: V1Node, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def create_persistent_volume(self, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def create_persistent_volume_with_http_info(self, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_config_map(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_config_map_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_endpoints(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_endpoints_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_event(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_event_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_limit_range(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_limit_range_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_persistent_volume_claim(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_persistent_volume_claim_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_pod(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_pod_template(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_pod_template_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_pod_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_replication_controller(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_replication_controller_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_resource_quota(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_resource_quota_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_secret(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_secret_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_service(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_service_account(self, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_namespaced_service_account_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_namespaced_service_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_node(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_node_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_collection_persistent_volume(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_persistent_volume_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespace(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespace_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_config_map(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_config_map_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_endpoints(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_endpoints_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_event(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_event_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_limit_range(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_limit_range_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_persistent_volume_claim(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def delete_namespaced_persistent_volume_claim_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def delete_namespaced_pod(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def delete_namespaced_pod_template(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1PodTemplate]: ...
    def delete_namespaced_pod_template_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PodTemplate, int, CIMultiDictProxy]]: ...
    def delete_namespaced_pod_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def delete_namespaced_replication_controller(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_replication_controller_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_resource_quota(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def delete_namespaced_resource_quota_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def delete_namespaced_secret(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_namespaced_secret_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_namespaced_service(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Service]: ...
    def delete_namespaced_service_account(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ServiceAccount]: ...
    def delete_namespaced_service_account_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccount, int, CIMultiDictProxy]]: ...
    def delete_namespaced_service_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def delete_node(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_node_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_persistent_volume(self, name: str, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def delete_persistent_volume_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_component_status(self, **kwargs: Any) -> Awaitable[V1ComponentStatusList]: ...
    def list_component_status_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ComponentStatusList, int, CIMultiDictProxy]]: ...
    def list_config_map_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ConfigMapList]: ...
    def list_config_map_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ConfigMapList, int, CIMultiDictProxy]]: ...
    def list_endpoints_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1EndpointsList]: ...
    def list_endpoints_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1EndpointsList, int, CIMultiDictProxy]]: ...
    def list_event_for_all_namespaces(self, **kwargs: Any) -> Awaitable[CoreV1EventList]: ...
    def list_event_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[CoreV1EventList, int, CIMultiDictProxy]]: ...
    def list_limit_range_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1LimitRangeList]: ...
    def list_limit_range_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1LimitRangeList, int, CIMultiDictProxy]]: ...
    def list_namespace(self, **kwargs: Any) -> Awaitable[V1NamespaceList]: ...
    def list_namespace_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1NamespaceList, int, CIMultiDictProxy]]: ...
    def list_namespaced_config_map(self, namespace: str, **kwargs: Any) -> Awaitable[V1ConfigMapList]: ...
    def list_namespaced_config_map_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ConfigMapList, int, CIMultiDictProxy]]: ...
    def list_namespaced_endpoints(self, namespace: str, **kwargs: Any) -> Awaitable[V1EndpointsList]: ...
    def list_namespaced_endpoints_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1EndpointsList, int, CIMultiDictProxy]]: ...
    def list_namespaced_event(self, namespace: str, **kwargs: Any) -> Awaitable[CoreV1EventList]: ...
    def list_namespaced_event_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[CoreV1EventList, int, CIMultiDictProxy]]: ...
    def list_namespaced_limit_range(self, namespace: str, **kwargs: Any) -> Awaitable[V1LimitRangeList]: ...
    def list_namespaced_limit_range_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1LimitRangeList, int, CIMultiDictProxy]]: ...
    def list_namespaced_persistent_volume_claim(self, namespace: str, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaimList]: ...
    def list_namespaced_persistent_volume_claim_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaimList, int, CIMultiDictProxy]]: ...
    def list_namespaced_pod(self, namespace: str, **kwargs: Any) -> Awaitable[V1PodList]: ...
    def list_namespaced_pod_template(self, namespace: str, **kwargs: Any) -> Awaitable[V1PodTemplateList]: ...
    def list_namespaced_pod_template_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PodTemplateList, int, CIMultiDictProxy]]: ...
    def list_namespaced_pod_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PodList, int, CIMultiDictProxy]]: ...
    def list_namespaced_replication_controller(self, namespace: str, **kwargs: Any) -> Awaitable[V1ReplicationControllerList]: ...
    def list_namespaced_replication_controller_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ReplicationControllerList, int, CIMultiDictProxy]]: ...
    def list_namespaced_resource_quota(self, namespace: str, **kwargs: Any) -> Awaitable[V1ResourceQuotaList]: ...
    def list_namespaced_resource_quota_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuotaList, int, CIMultiDictProxy]]: ...
    def list_namespaced_secret(self, namespace: str, **kwargs: Any) -> Awaitable[V1SecretList]: ...
    def list_namespaced_secret_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1SecretList, int, CIMultiDictProxy]]: ...
    def list_namespaced_service(self, namespace: str, **kwargs: Any) -> Awaitable[V1ServiceList]: ...
    def list_namespaced_service_account(self, namespace: str, **kwargs: Any) -> Awaitable[V1ServiceAccountList]: ...
    def list_namespaced_service_account_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccountList, int, CIMultiDictProxy]]: ...
    def list_namespaced_service_with_http_info(self, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ServiceList, int, CIMultiDictProxy]]: ...
    def list_node(self, **kwargs: Any) -> Awaitable[V1NodeList]: ...
    def list_node_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1NodeList, int, CIMultiDictProxy]]: ...
    def list_persistent_volume(self, **kwargs: Any) -> Awaitable[V1PersistentVolumeList]: ...
    def list_persistent_volume_claim_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaimList]: ...
    def list_persistent_volume_claim_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaimList, int, CIMultiDictProxy]]: ...
    def list_persistent_volume_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeList, int, CIMultiDictProxy]]: ...
    def list_pod_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1PodList]: ...
    def list_pod_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1PodList, int, CIMultiDictProxy]]: ...
    def list_pod_template_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1PodTemplateList]: ...
    def list_pod_template_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1PodTemplateList, int, CIMultiDictProxy]]: ...
    def list_replication_controller_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ReplicationControllerList]: ...
    def list_replication_controller_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ReplicationControllerList, int, CIMultiDictProxy]]: ...
    def list_resource_quota_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ResourceQuotaList]: ...
    def list_resource_quota_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuotaList, int, CIMultiDictProxy]]: ...
    def list_secret_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1SecretList]: ...
    def list_secret_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1SecretList, int, CIMultiDictProxy]]: ...
    def list_service_account_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ServiceAccountList]: ...
    def list_service_account_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccountList, int, CIMultiDictProxy]]: ...
    def list_service_for_all_namespaces(self, **kwargs: Any) -> Awaitable[V1ServiceList]: ...
    def list_service_for_all_namespaces_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1ServiceList, int, CIMultiDictProxy]]: ...
    def patch_namespace(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def patch_namespace_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def patch_namespace_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def patch_namespace_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def patch_namespaced_config_map(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ConfigMap]: ...
    def patch_namespaced_config_map_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ConfigMap, int, CIMultiDictProxy]]: ...
    def patch_namespaced_endpoints(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Endpoints]: ...
    def patch_namespaced_endpoints_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Endpoints, int, CIMultiDictProxy]]: ...
    def patch_namespaced_event(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[CoreV1Event]: ...
    def patch_namespaced_event_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[CoreV1Event, int, CIMultiDictProxy]]: ...
    def patch_namespaced_limit_range(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1LimitRange]: ...
    def patch_namespaced_limit_range_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1LimitRange, int, CIMultiDictProxy]]: ...
    def patch_namespaced_persistent_volume_claim(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def patch_namespaced_persistent_volume_claim_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def patch_namespaced_persistent_volume_claim_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def patch_namespaced_persistent_volume_claim_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def patch_namespaced_pod(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def patch_namespaced_pod_ephemeralcontainers(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def patch_namespaced_pod_ephemeralcontainers_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def patch_namespaced_pod_resize(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def patch_namespaced_pod_resize_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def patch_namespaced_pod_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def patch_namespaced_pod_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def patch_namespaced_pod_template(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1PodTemplate]: ...
    def patch_namespaced_pod_template_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PodTemplate, int, CIMultiDictProxy]]: ...
    def patch_namespaced_pod_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def patch_namespaced_replication_controller(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def patch_namespaced_replication_controller_scale(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def patch_namespaced_replication_controller_scale_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def patch_namespaced_replication_controller_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def patch_namespaced_replication_controller_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def patch_namespaced_replication_controller_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def patch_namespaced_resource_quota(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def patch_namespaced_resource_quota_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def patch_namespaced_resource_quota_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def patch_namespaced_resource_quota_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def patch_namespaced_secret(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Secret]: ...
    def patch_namespaced_secret_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Secret, int, CIMultiDictProxy]]: ...
    def patch_namespaced_service(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Service]: ...
    def patch_namespaced_service_account(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1ServiceAccount]: ...
    def patch_namespaced_service_account_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccount, int, CIMultiDictProxy]]: ...
    def patch_namespaced_service_status(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[V1Service]: ...
    def patch_namespaced_service_status_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def patch_namespaced_service_with_http_info(self, name: str, namespace: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def patch_node(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1Node]: ...
    def patch_node_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1Node]: ...
    def patch_node_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def patch_node_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def patch_persistent_volume(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def patch_persistent_volume_status(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def patch_persistent_volume_status_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def patch_persistent_volume_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def read_component_status(self, name: str, **kwargs: Any) -> Awaitable[V1ComponentStatus]: ...
    def read_component_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1ComponentStatus, int, CIMultiDictProxy]]: ...
    def read_namespace(self, name: str, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def read_namespace_status(self, name: str, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def read_namespace_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def read_namespace_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def read_namespaced_config_map(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ConfigMap]: ...
    def read_namespaced_config_map_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ConfigMap, int, CIMultiDictProxy]]: ...
    def read_namespaced_endpoints(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Endpoints]: ...
    def read_namespaced_endpoints_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Endpoints, int, CIMultiDictProxy]]: ...
    def read_namespaced_event(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[CoreV1Event]: ...
    def read_namespaced_event_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[CoreV1Event, int, CIMultiDictProxy]]: ...
    def read_namespaced_limit_range(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1LimitRange]: ...
    def read_namespaced_limit_range_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1LimitRange, int, CIMultiDictProxy]]: ...
    def read_namespaced_persistent_volume_claim(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def read_namespaced_persistent_volume_claim_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def read_namespaced_persistent_volume_claim_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def read_namespaced_persistent_volume_claim_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def read_namespaced_pod_ephemeralcontainers(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def read_namespaced_pod_ephemeralcontainers_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod_log(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[str]: ...
    def read_namespaced_pod_log_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod_resize(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def read_namespaced_pod_resize_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def read_namespaced_pod_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod_template(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1PodTemplate]: ...
    def read_namespaced_pod_template_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1PodTemplate, int, CIMultiDictProxy]]: ...
    def read_namespaced_pod_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def read_namespaced_replication_controller(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def read_namespaced_replication_controller_scale(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def read_namespaced_replication_controller_scale_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def read_namespaced_replication_controller_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def read_namespaced_replication_controller_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def read_namespaced_replication_controller_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def read_namespaced_resource_quota(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def read_namespaced_resource_quota_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def read_namespaced_resource_quota_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def read_namespaced_resource_quota_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def read_namespaced_secret(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Secret]: ...
    def read_namespaced_secret_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Secret, int, CIMultiDictProxy]]: ...
    def read_namespaced_service(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Service]: ...
    def read_namespaced_service_account(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1ServiceAccount]: ...
    def read_namespaced_service_account_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccount, int, CIMultiDictProxy]]: ...
    def read_namespaced_service_status(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[V1Service]: ...
    def read_namespaced_service_status_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def read_namespaced_service_with_http_info(self, name: str, namespace: str, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def read_node(self, name: str, **kwargs: Any) -> Awaitable[V1Node]: ...
    def read_node_status(self, name: str, **kwargs: Any) -> Awaitable[V1Node]: ...
    def read_node_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def read_node_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def read_persistent_volume(self, name: str, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def read_persistent_volume_status(self, name: str, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def read_persistent_volume_status_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def read_persistent_volume_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def replace_namespace(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def replace_namespace_finalize(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def replace_namespace_finalize_with_http_info(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def replace_namespace_status(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[V1Namespace]: ...
    def replace_namespace_status_with_http_info(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def replace_namespace_with_http_info(self, name: str, body: V1Namespace, **kwargs: Any) -> Awaitable[tuple[V1Namespace, int, CIMultiDictProxy]]: ...
    def replace_namespaced_config_map(self, name: str, namespace: str, body: V1ConfigMap, **kwargs: Any) -> Awaitable[V1ConfigMap]: ...
    def replace_namespaced_config_map_with_http_info(self, name: str, namespace: str, body: V1ConfigMap, **kwargs: Any) -> Awaitable[tuple[V1ConfigMap, int, CIMultiDictProxy]]: ...
    def replace_namespaced_endpoints(self, name: str, namespace: str, body: V1Endpoints, **kwargs: Any) -> Awaitable[V1Endpoints]: ...
    def replace_namespaced_endpoints_with_http_info(self, name: str, namespace: str, body: V1Endpoints, **kwargs: Any) -> Awaitable[tuple[V1Endpoints, int, CIMultiDictProxy]]: ...
    def replace_namespaced_event(self, name: str, namespace: str, body: CoreV1Event, **kwargs: Any) -> Awaitable[CoreV1Event]: ...
    def replace_namespaced_event_with_http_info(self, name: str, namespace: str, body: CoreV1Event, **kwargs: Any) -> Awaitable[tuple[CoreV1Event, int, CIMultiDictProxy]]: ...
    def replace_namespaced_limit_range(self, name: str, namespace: str, body: V1LimitRange, **kwargs: Any) -> Awaitable[V1LimitRange]: ...
    def replace_namespaced_limit_range_with_http_info(self, name: str, namespace: str, body: V1LimitRange, **kwargs: Any) -> Awaitable[tuple[V1LimitRange, int, CIMultiDictProxy]]: ...
    def replace_namespaced_persistent_volume_claim(self, name: str, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def replace_namespaced_persistent_volume_claim_status(self, name: str, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[V1PersistentVolumeClaim]: ...
    def replace_namespaced_persistent_volume_claim_status_with_http_info(self, name: str, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def replace_namespaced_persistent_volume_claim_with_http_info(self, name: str, namespace: str, body: V1PersistentVolumeClaim, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolumeClaim, int, CIMultiDictProxy]]: ...
    def replace_namespaced_pod(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def replace_namespaced_pod_ephemeralcontainers(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def replace_namespaced_pod_ephemeralcontainers_with_http_info(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def replace_namespaced_pod_resize(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def replace_namespaced_pod_resize_with_http_info(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def replace_namespaced_pod_status(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[V1Pod]: ...
    def replace_namespaced_pod_status_with_http_info(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def replace_namespaced_pod_template(self, name: str, namespace: str, body: V1PodTemplate, **kwargs: Any) -> Awaitable[V1PodTemplate]: ...
    def replace_namespaced_pod_template_with_http_info(self, name: str, namespace: str, body: V1PodTemplate, **kwargs: Any) -> Awaitable[tuple[V1PodTemplate, int, CIMultiDictProxy]]: ...
    def replace_namespaced_pod_with_http_info(self, name: str, namespace: str, body: V1Pod, **kwargs: Any) -> Awaitable[tuple[V1Pod, int, CIMultiDictProxy]]: ...
    def replace_namespaced_replication_controller(self, name: str, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def replace_namespaced_replication_controller_scale(self, name: str, namespace: str, body: V1Scale, **kwargs: Any) -> Awaitable[V1Scale]: ...
    def replace_namespaced_replication_controller_scale_with_http_info(self, name: str, namespace: str, body: V1Scale, **kwargs: Any) -> Awaitable[tuple[V1Scale, int, CIMultiDictProxy]]: ...
    def replace_namespaced_replication_controller_status(self, name: str, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[V1ReplicationController]: ...
    def replace_namespaced_replication_controller_status_with_http_info(self, name: str, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def replace_namespaced_replication_controller_with_http_info(self, name: str, namespace: str, body: V1ReplicationController, **kwargs: Any) -> Awaitable[tuple[V1ReplicationController, int, CIMultiDictProxy]]: ...
    def replace_namespaced_resource_quota(self, name: str, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def replace_namespaced_resource_quota_status(self, name: str, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[V1ResourceQuota]: ...
    def replace_namespaced_resource_quota_status_with_http_info(self, name: str, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def replace_namespaced_resource_quota_with_http_info(self, name: str, namespace: str, body: V1ResourceQuota, **kwargs: Any) -> Awaitable[tuple[V1ResourceQuota, int, CIMultiDictProxy]]: ...
    def replace_namespaced_secret(self, name: str, namespace: str, body: V1Secret, **kwargs: Any) -> Awaitable[V1Secret]: ...
    def replace_namespaced_secret_with_http_info(self, name: str, namespace: str, body: V1Secret, **kwargs: Any) -> Awaitable[tuple[V1Secret, int, CIMultiDictProxy]]: ...
    def replace_namespaced_service(self, name: str, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[V1Service]: ...
    def replace_namespaced_service_account(self, name: str, namespace: str, body: V1ServiceAccount, **kwargs: Any) -> Awaitable[V1ServiceAccount]: ...
    def replace_namespaced_service_account_with_http_info(self, name: str, namespace: str, body: V1ServiceAccount, **kwargs: Any) -> Awaitable[tuple[V1ServiceAccount, int, CIMultiDictProxy]]: ...
    def replace_namespaced_service_status(self, name: str, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[V1Service]: ...
    def replace_namespaced_service_status_with_http_info(self, name: str, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def replace_namespaced_service_with_http_info(self, name: str, namespace: str, body: V1Service, **kwargs: Any) -> Awaitable[tuple[V1Service, int, CIMultiDictProxy]]: ...
    def replace_node(self, name: str, body: V1Node, **kwargs: Any) -> Awaitable[V1Node]: ...
    def replace_node_status(self, name: str, body: V1Node, **kwargs: Any) -> Awaitable[V1Node]: ...
    def replace_node_status_with_http_info(self, name: str, body: V1Node, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def replace_node_with_http_info(self, name: str, body: V1Node, **kwargs: Any) -> Awaitable[tuple[V1Node, int, CIMultiDictProxy]]: ...
    def replace_persistent_volume(self, name: str, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def replace_persistent_volume_status(self, name: str, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[V1PersistentVolume]: ...
    def replace_persistent_volume_status_with_http_info(self, name: str, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...
    def replace_persistent_volume_with_http_info(self, name: str, body: V1PersistentVolume, **kwargs: Any) -> Awaitable[tuple[V1PersistentVolume, int, CIMultiDictProxy]]: ...



from kubernetes_asyncio.client.api_client import ApiClient
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class WellKnownApi:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def get_service_account_issuer_open_id_configuration(self, **kwargs: Any) -> Awaitable[str]: ...
    def get_service_account_issuer_open_id_configuration_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[str, int, CIMultiDictProxy]]: ...



from kubernetes_asyncio.client.models import V1ListMeta
from kubernetes_asyncio.client.models import V1StatusDetails
from typing import Any

class V1Status:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, api_version: str | None = None, code: int | None = None, details: V1StatusDetails | None = None, kind: str | None = None, message: str | None = None, metadata: V1ListMeta | None = None, reason: str | None = None, status: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def api_version(self) -> str: ...
    @api_version.setter
    def api_version(self, api_version: str) -> None: ...
    @property
    def code(self) -> int: ...
    @code.setter
    def code(self, code: int) -> None: ...
    @property
    def details(self) -> V1StatusDetails: ...
    @details.setter
    def details(self, details: V1StatusDetails) -> None: ...
    @property
    def kind(self) -> str: ...
    @kind.setter
    def kind(self, kind: str) -> None: ...
    @property
    def message(self) -> str: ...
    @message.setter
    def message(self, message: str) -> None: ...
    @property
    def metadata(self) -> V1ListMeta: ...
    @metadata.setter
    def metadata(self, metadata: V1ListMeta) -> None: ...
    @property
    def reason(self) -> str: ...
    @reason.setter
    def reason(self, reason: str) -> None: ...
    @property
    def status(self) -> str: ...
    @status.setter
    def status(self, status: str) -> None: ...



from kubernetes_asyncio.client.models import V1NodeSelector
from kubernetes_asyncio.client.models import V1beta1DeviceAttribute
from kubernetes_asyncio.client.models import V1beta1DeviceCapacity
from kubernetes_asyncio.client.models import V1beta1DeviceCounterConsumption
from kubernetes_asyncio.client.models import V1beta1DeviceTaint
from typing import Any

class V1beta1BasicDevice:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, all_nodes: bool | None = None, allow_multiple_allocations: bool | None = None, attributes: dict[str, V1beta1DeviceAttribute] | None = None, binding_conditions: list[str] | None = None, binding_failure_conditions: list[str] | None = None, binds_to_node: bool | None = None, capacity: dict[str, V1beta1DeviceCapacity] | None = None, consumes_counters: list[V1beta1DeviceCounterConsumption] | None = None, node_name: str | None = None, node_selector: V1NodeSelector | None = None, taints: list[V1beta1DeviceTaint] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def all_nodes(self) -> bool: ...
    @all_nodes.setter
    def all_nodes(self, all_nodes: bool) -> None: ...
    @property
    def allow_multiple_allocations(self) -> bool: ...
    @allow_multiple_allocations.setter
    def allow_multiple_allocations(self, allow_multiple_allocations: bool) -> None: ...
    @property
    def attributes(self) -> dict[str, V1beta1DeviceAttribute]: ...
    @attributes.setter
    def attributes(self, attributes: dict[str, V1beta1DeviceAttribute]) -> None: ...
    @property
    def binding_conditions(self) -> list[str]: ...
    @binding_conditions.setter
    def binding_conditions(self, binding_conditions: list[str]) -> None: ...
    @property
    def binding_failure_conditions(self) -> list[str]: ...
    @binding_failure_conditions.setter
    def binding_failure_conditions(self, binding_failure_conditions: list[str]) -> None: ...
    @property
    def binds_to_node(self) -> bool: ...
    @binds_to_node.setter
    def binds_to_node(self, binds_to_node: bool) -> None: ...
    @property
    def capacity(self) -> dict[str, V1beta1DeviceCapacity]: ...
    @capacity.setter
    def capacity(self, capacity: dict[str, V1beta1DeviceCapacity]) -> None: ...
    @property
    def consumes_counters(self) -> list[V1beta1DeviceCounterConsumption]: ...
    @consumes_counters.setter
    def consumes_counters(self, consumes_counters: list[V1beta1DeviceCounterConsumption]) -> None: ...
    @property
    def node_name(self) -> str: ...
    @node_name.setter
    def node_name(self, node_name: str) -> None: ...
    @property
    def node_selector(self) -> V1NodeSelector: ...
    @node_selector.setter
    def node_selector(self, node_selector: V1NodeSelector) -> None: ...
    @property
    def taints(self) -> list[V1beta1DeviceTaint]: ...
    @taints.setter
    def taints(self, taints: list[V1beta1DeviceTaint]) -> None: ...



from kubernetes_asyncio.client.models import V1LabelSelector
from kubernetes_asyncio.client.models import V1TypedLocalObjectReference
from kubernetes_asyncio.client.models import V1TypedObjectReference
from kubernetes_asyncio.client.models import V1VolumeResourceRequirements
from typing import Any

class V1PersistentVolumeClaimSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, access_modes: list[str] | None = None, data_source: V1TypedLocalObjectReference | None = None, data_source_ref: V1TypedObjectReference | None = None, resources: V1VolumeResourceRequirements | None = None, selector: V1LabelSelector | None = None, storage_class_name: str | None = None, volume_attributes_class_name: str | None = None, volume_mode: str | None = None, volume_name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def access_modes(self) -> list[str]: ...
    @access_modes.setter
    def access_modes(self, access_modes: list[str]) -> None: ...
    @property
    def data_source(self) -> V1TypedLocalObjectReference: ...
    @data_source.setter
    def data_source(self, data_source: V1TypedLocalObjectReference) -> None: ...
    @property
    def data_source_ref(self) -> V1TypedObjectReference: ...
    @data_source_ref.setter
    def data_source_ref(self, data_source_ref: V1TypedObjectReference) -> None: ...
    @property
    def resources(self) -> V1VolumeResourceRequirements: ...
    @resources.setter
    def resources(self, resources: V1VolumeResourceRequirements) -> None: ...
    @property
    def selector(self) -> V1LabelSelector: ...
    @selector.setter
    def selector(self, selector: V1LabelSelector) -> None: ...
    @property
    def storage_class_name(self) -> str: ...
    @storage_class_name.setter
    def storage_class_name(self, storage_class_name: str) -> None: ...
    @property
    def volume_attributes_class_name(self) -> str: ...
    @volume_attributes_class_name.setter
    def volume_attributes_class_name(self, volume_attributes_class_name: str) -> None: ...
    @property
    def volume_mode(self) -> str: ...
    @volume_mode.setter
    def volume_mode(self, volume_mode: str) -> None: ...
    @property
    def volume_name(self) -> str: ...
    @volume_name.setter
    def volume_name(self, volume_name: str) -> None: ...



from kubernetes_asyncio.client.models import V1ContainerState
from kubernetes_asyncio.client.models import V1ContainerUser
from kubernetes_asyncio.client.models import V1ResourceRequirements
from kubernetes_asyncio.client.models import V1ResourceStatus
from kubernetes_asyncio.client.models import V1VolumeMountStatus
from typing import Any

class V1ContainerStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, allocated_resources: dict[str, str] | None = None, allocated_resources_status: list[V1ResourceStatus] | None = None, container_id: str | None = None, image: str | None = None, image_id: str | None = None, last_state: V1ContainerState | None = None, name: str | None = None, ready: bool | None = None, resources: V1ResourceRequirements | None = None, restart_count: int | None = None, started: bool | None = None, state: V1ContainerState | None = None, stop_signal: str | None = None, user: V1ContainerUser | None = None, volume_mounts: list[V1VolumeMountStatus] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def allocated_resources(self) -> dict[str, str]: ...
    @allocated_resources.setter
    def allocated_resources(self, allocated_resources: dict[str, str]) -> None: ...
    @property
    def allocated_resources_status(self) -> list[V1ResourceStatus]: ...
    @allocated_resources_status.setter
    def allocated_resources_status(self, allocated_resources_status: list[V1ResourceStatus]) -> None: ...
    @property
    def container_id(self) -> str: ...
    @container_id.setter
    def container_id(self, container_id: str) -> None: ...
    @property
    def image(self) -> str: ...
    @image.setter
    def image(self, image: str) -> None: ...
    @property
    def image_id(self) -> str: ...
    @image_id.setter
    def image_id(self, image_id: str) -> None: ...
    @property
    def last_state(self) -> V1ContainerState: ...
    @last_state.setter
    def last_state(self, last_state: V1ContainerState) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
    @property
    def ready(self) -> bool: ...
    @ready.setter
    def ready(self, ready: bool) -> None: ...
    @property
    def resources(self) -> V1ResourceRequirements: ...
    @resources.setter
    def resources(self, resources: V1ResourceRequirements) -> None: ...
    @property
    def restart_count(self) -> int: ...
    @restart_count.setter
    def restart_count(self, restart_count: int) -> None: ...
    @property
    def started(self) -> bool: ...
    @started.setter
    def started(self, started: bool) -> None: ...
    @property
    def state(self) -> V1ContainerState: ...
    @state.setter
    def state(self, state: V1ContainerState) -> None: ...
    @property
    def stop_signal(self) -> str: ...
    @stop_signal.setter
    def stop_signal(self, stop_signal: str) -> None: ...
    @property
    def user(self) -> V1ContainerUser: ...
    @user.setter
    def user(self, user: V1ContainerUser) -> None: ...
    @property
    def volume_mounts(self) -> list[V1VolumeMountStatus]: ...
    @volume_mounts.setter
    def volume_mounts(self, volume_mounts: list[V1VolumeMountStatus]) -> None: ...



from typing import Any

class V1beta1DeviceAttribute:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, bool: bool | None = None, int: int | None = None, string: str | None = None, version: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def bool(self) -> bool: ...
    @bool.setter
    def bool(self, bool: bool) -> None: ...
    @property
    def int(self) -> int: ...
    @int.setter
    def int(self, int: int) -> None: ...
    @property
    def string(self) -> str: ...
    @string.setter
    def string(self, string: str) -> None: ...
    @property
    def version(self) -> str: ...
    @version.setter
    def version(self, version: str) -> None: ...



from aiohttp import ClientResponse
from multidict import CIMultiDictProxy

class OpenApiException(Exception): ...

class ApiTypeError(OpenApiException, TypeError):
    path_to_item: list | None
    valid_classes: tuple | None
    key_type: bool | None
    def __init__(
        self,
        msg: str,
        path_to_item: list | None = None,
        valid_classes: tuple | None = None,
        key_type: bool | None = None,
    ) -> None: ...

class ApiValueError(OpenApiException, ValueError):
    path_to_item: list | None
    def __init__(self, msg: str, path_to_item: list | None = None) -> None: ...

class ApiAttributeError(OpenApiException, AttributeError):
    path_to_item: list | None
    def __init__(self, msg: str, path_to_item: list | None = None) -> None: ...

class ApiKeyError(OpenApiException, KeyError):
    path_to_item: list | None
    def __init__(self, msg: str, path_to_item: list | None = None) -> None: ...

class ApiException(OpenApiException):
    status: int
    reason: str | None
    body: bytes | None
    headers: CIMultiDictProxy | None
    def __init__(
        self,
        status: int | None = None,
        reason: str | None = None,
        http_resp: ClientResponse | None = None,
    ) -> None: ...

class NotFoundException(ApiException):
    def __init__(
        self,
        status: int | None = None,
        reason: str | None = None,
        http_resp: ClientResponse | None = None,
    ) -> None: ...

class UnauthorizedException(ApiException):
    def __init__(
        self,
        status: int | None = None,
        reason: str | None = None,
        http_resp: ClientResponse | None = None,
    ) -> None: ...

class ForbiddenException(ApiException):
    def __init__(
        self,
        status: int | None = None,
        reason: str | None = None,
        http_resp: ClientResponse | None = None,
    ) -> None: ...

class ServiceException(ApiException):
    def __init__(
        self,
        status: int | None = None,
        reason: str | None = None,
        http_resp: ClientResponse | None = None,
    ) -> None: ...

def render_path(path_to_item): ...



from kubernetes_asyncio.client.models import V1LabelSelector
from kubernetes_asyncio.client.models import V1PodTemplateSpec
from typing import Any

class V1ReplicaSetSpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, min_ready_seconds: int | None = None, replicas: int | None = None, selector: V1LabelSelector | None = None, template: V1PodTemplateSpec | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def min_ready_seconds(self) -> int: ...
    @min_ready_seconds.setter
    def min_ready_seconds(self, min_ready_seconds: int) -> None: ...
    @property
    def replicas(self) -> int: ...
    @replicas.setter
    def replicas(self, replicas: int) -> None: ...
    @property
    def selector(self) -> V1LabelSelector: ...
    @selector.setter
    def selector(self, selector: V1LabelSelector) -> None: ...
    @property
    def template(self) -> V1PodTemplateSpec: ...
    @template.setter
    def template(self, template: V1PodTemplateSpec) -> None: ...



from datetime import datetime
from kubernetes_asyncio.client.models import V1Condition
from typing import Any

class V1PodDisruptionBudgetStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, conditions: list[V1Condition] | None = None, current_healthy: int | None = None, desired_healthy: int | None = None, disrupted_pods: dict[str, datetime] | None = None, disruptions_allowed: int | None = None, expected_pods: int | None = None, observed_generation: int | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def conditions(self) -> list[V1Condition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1Condition]) -> None: ...
    @property
    def current_healthy(self) -> int: ...
    @current_healthy.setter
    def current_healthy(self, current_healthy: int) -> None: ...
    @property
    def desired_healthy(self) -> int: ...
    @desired_healthy.setter
    def desired_healthy(self, desired_healthy: int) -> None: ...
    @property
    def disrupted_pods(self) -> dict[str, datetime]: ...
    @disrupted_pods.setter
    def disrupted_pods(self, disrupted_pods: dict[str, datetime]) -> None: ...
    @property
    def disruptions_allowed(self) -> int: ...
    @disruptions_allowed.setter
    def disruptions_allowed(self, disruptions_allowed: int) -> None: ...
    @property
    def expected_pods(self) -> int: ...
    @expected_pods.setter
    def expected_pods(self, expected_pods: int) -> None: ...
    @property
    def observed_generation(self) -> int: ...
    @observed_generation.setter
    def observed_generation(self, observed_generation: int) -> None: ...



from typing import Any

class V1Capabilities:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, add: list[str] | None = None, drop: list[str] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def add(self) -> list[str]: ...
    @add.setter
    def add(self, add: list[str]) -> None: ...
    @property
    def drop(self) -> list[str]: ...
    @drop.setter
    def drop(self, drop: list[str]) -> None: ...



from kubernetes_asyncio.client.models import V1ConfigMapEnvSource
from kubernetes_asyncio.client.models import V1SecretEnvSource
from typing import Any

class V1EnvFromSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, config_map_ref: V1ConfigMapEnvSource | None = None, prefix: str | None = None, secret_ref: V1SecretEnvSource | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def config_map_ref(self) -> V1ConfigMapEnvSource: ...
    @config_map_ref.setter
    def config_map_ref(self, config_map_ref: V1ConfigMapEnvSource) -> None: ...
    @property
    def prefix(self) -> str: ...
    @prefix.setter
    def prefix(self, prefix: str) -> None: ...
    @property
    def secret_ref(self) -> V1SecretEnvSource: ...
    @secret_ref.setter
    def secret_ref(self, secret_ref: V1SecretEnvSource) -> None: ...



from kubernetes_asyncio.client.models import V1Condition
from kubernetes_asyncio.client.models import V1beta1NetworkDeviceData
from typing import Any

class V1beta1AllocatedDeviceStatus:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, conditions: list[V1Condition] | None = None, data: Any | None = None, device: str | None = None, driver: str | None = None, network_data: V1beta1NetworkDeviceData | None = None, pool: str | None = None, share_id: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def conditions(self) -> list[V1Condition]: ...
    @conditions.setter
    def conditions(self, conditions: list[V1Condition]) -> None: ...
    @property
    def data(self) -> Any: ...
    @data.setter
    def data(self, data: Any) -> None: ...
    @property
    def device(self) -> str: ...
    @device.setter
    def device(self, device: str) -> None: ...
    @property
    def driver(self) -> str: ...
    @driver.setter
    def driver(self, driver: str) -> None: ...
    @property
    def network_data(self) -> V1beta1NetworkDeviceData: ...
    @network_data.setter
    def network_data(self, network_data: V1beta1NetworkDeviceData) -> None: ...
    @property
    def pool(self) -> str: ...
    @pool.setter
    def pool(self, pool: str) -> None: ...
    @property
    def share_id(self) -> str: ...
    @share_id.setter
    def share_id(self, share_id: str) -> None: ...



from kubernetes_asyncio.client.models import FlowcontrolV1Subject
from kubernetes_asyncio.client.models import V1NonResourcePolicyRule
from kubernetes_asyncio.client.models import V1ResourcePolicyRule
from typing import Any

class V1PolicyRulesWithSubjects:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, non_resource_rules: list[V1NonResourcePolicyRule] | None = None, resource_rules: list[V1ResourcePolicyRule] | None = None, subjects: list[FlowcontrolV1Subject] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def non_resource_rules(self) -> list[V1NonResourcePolicyRule]: ...
    @non_resource_rules.setter
    def non_resource_rules(self, non_resource_rules: list[V1NonResourcePolicyRule]) -> None: ...
    @property
    def resource_rules(self) -> list[V1ResourcePolicyRule]: ...
    @resource_rules.setter
    def resource_rules(self, resource_rules: list[V1ResourcePolicyRule]) -> None: ...
    @property
    def subjects(self) -> list[FlowcontrolV1Subject]: ...
    @subjects.setter
    def subjects(self, subjects: list[FlowcontrolV1Subject]) -> None: ...



from kubernetes_asyncio.client.models import V1AppArmorProfile
from kubernetes_asyncio.client.models import V1SELinuxOptions
from kubernetes_asyncio.client.models import V1SeccompProfile
from kubernetes_asyncio.client.models import V1Sysctl
from kubernetes_asyncio.client.models import V1WindowsSecurityContextOptions
from typing import Any

class V1PodSecurityContext:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, app_armor_profile: V1AppArmorProfile | None = None, fs_group: int | None = None, fs_group_change_policy: str | None = None, run_as_group: int | None = None, run_as_non_root: bool | None = None, run_as_user: int | None = None, se_linux_change_policy: str | None = None, se_linux_options: V1SELinuxOptions | None = None, seccomp_profile: V1SeccompProfile | None = None, supplemental_groups: list[int] | None = None, supplemental_groups_policy: str | None = None, sysctls: list[V1Sysctl] | None = None, windows_options: V1WindowsSecurityContextOptions | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def app_armor_profile(self) -> V1AppArmorProfile: ...
    @app_armor_profile.setter
    def app_armor_profile(self, app_armor_profile: V1AppArmorProfile) -> None: ...
    @property
    def fs_group(self) -> int: ...
    @fs_group.setter
    def fs_group(self, fs_group: int) -> None: ...
    @property
    def fs_group_change_policy(self) -> str: ...
    @fs_group_change_policy.setter
    def fs_group_change_policy(self, fs_group_change_policy: str) -> None: ...
    @property
    def run_as_group(self) -> int: ...
    @run_as_group.setter
    def run_as_group(self, run_as_group: int) -> None: ...
    @property
    def run_as_non_root(self) -> bool: ...
    @run_as_non_root.setter
    def run_as_non_root(self, run_as_non_root: bool) -> None: ...
    @property
    def run_as_user(self) -> int: ...
    @run_as_user.setter
    def run_as_user(self, run_as_user: int) -> None: ...
    @property
    def se_linux_change_policy(self) -> str: ...
    @se_linux_change_policy.setter
    def se_linux_change_policy(self, se_linux_change_policy: str) -> None: ...
    @property
    def se_linux_options(self) -> V1SELinuxOptions: ...
    @se_linux_options.setter
    def se_linux_options(self, se_linux_options: V1SELinuxOptions) -> None: ...
    @property
    def seccomp_profile(self) -> V1SeccompProfile: ...
    @seccomp_profile.setter
    def seccomp_profile(self, seccomp_profile: V1SeccompProfile) -> None: ...
    @property
    def supplemental_groups(self) -> list[int]: ...
    @supplemental_groups.setter
    def supplemental_groups(self, supplemental_groups: list[int]) -> None: ...
    @property
    def supplemental_groups_policy(self) -> str: ...
    @supplemental_groups_policy.setter
    def supplemental_groups_policy(self, supplemental_groups_policy: str) -> None: ...
    @property
    def sysctls(self) -> list[V1Sysctl]: ...
    @sysctls.setter
    def sysctls(self, sysctls: list[V1Sysctl]) -> None: ...
    @property
    def windows_options(self) -> V1WindowsSecurityContextOptions: ...
    @windows_options.setter
    def windows_options(self, windows_options: V1WindowsSecurityContextOptions) -> None: ...



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.34.3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes_asyncio.client.configuration import Configuration


class V1PodStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'conditions': 'list[V1PodCondition]',
        'container_statuses': 'list[V1ContainerStatus]',
        'ephemeral_container_statuses': 'list[V1ContainerStatus]',
        'extended_resource_claim_status': 'V1PodExtendedResourceClaimStatus',
        'host_ip': 'str',
        'host_ips': 'list[V1HostIP]',
        'init_container_statuses': 'list[V1ContainerStatus]',
        'message': 'str',
        'nominated_node_name': 'str',
        'observed_generation': 'int',
        'phase': 'str',
        'pod_ip': 'str',
        'pod_ips': 'list[V1PodIP]',
        'qos_class': 'str',
        'reason': 'str',
        'resize': 'str',
        'resource_claim_statuses': 'list[V1PodResourceClaimStatus]',
        'start_time': 'datetime'
    }

    attribute_map = {
        'conditions': 'conditions',
        'container_statuses': 'containerStatuses',
        'ephemeral_container_statuses': 'ephemeralContainerStatuses',
        'extended_resource_claim_status': 'extendedResourceClaimStatus',
        'host_ip': 'hostIP',
        'host_ips': 'hostIPs',
        'init_container_statuses': 'initContainerStatuses',
        'message': 'message',
        'nominated_node_name': 'nominatedNodeName',
        'observed_generation': 'observedGeneration',
        'phase': 'phase',
        'pod_ip': 'podIP',
        'pod_ips': 'podIPs',
        'qos_class': 'qosClass',
        'reason': 'reason',
        'resize': 'resize',
        'resource_claim_statuses': 'resourceClaimStatuses',
        'start_time': 'startTime'
    }

    def __init__(self, conditions=None, container_statuses=None, ephemeral_container_statuses=None, extended_resource_claim_status=None, host_ip=None, host_ips=None, init_container_statuses=None, message=None, nominated_node_name=None, observed_generation=None, phase=None, pod_ip=None, pod_ips=None, qos_class=None, reason=None, resize=None, resource_claim_statuses=None, start_time=None, local_vars_configuration=None):  # noqa: E501
        """V1PodStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default()
        self.local_vars_configuration = local_vars_configuration

        self._conditions = None
        self._container_statuses = None
        self._ephemeral_container_statuses = None
        self._extended_resource_claim_status = None
        self._host_ip = None
        self._host_ips = None
        self._init_container_statuses = None
        self._message = None
        self._nominated_node_name = None
        self._observed_generation = None
        self._phase = None
        self._pod_ip = None
        self._pod_ips = None
        self._qos_class = None
        self._reason = None
        self._resize = None
        self._resource_claim_statuses = None
        self._start_time = None
        self.discriminator = None

        if conditions is not None:
            self.conditions = conditions
        if container_statuses is not None:
            self.container_statuses = container_statuses
        if ephemeral_container_statuses is not None:
            self.ephemeral_container_statuses = ephemeral_container_statuses
        if extended_resource_claim_status is not None:
            self.extended_resource_claim_status = extended_resource_claim_status
        if host_ip is not None:
            self.host_ip = host_ip
        if host_ips is not None:
            self.host_ips = host_ips
        if init_container_statuses is not None:
            self.init_container_statuses = init_container_statuses
        if message is not None:
            self.message = message
        if nominated_node_name is not None:
            self.nominated_node_name = nominated_node_name
        if observed_generation is not None:
            self.observed_generation = observed_generation
        if phase is not None:
            self.phase = phase
        if pod_ip is not None:
            self.pod_ip = pod_ip
        if pod_ips is not None:
            self.pod_ips = pod_ips
        if qos_class is not None:
            self.qos_class = qos_class
        if reason is not None:
            self.reason = reason
        if resize is not None:
            self.resize = resize
        if resource_claim_statuses is not None:
            self.resource_claim_statuses = resource_claim_statuses
        if start_time is not None:
            self.start_time = start_time

    @property
    def conditions(self):
        """Gets the conditions of this V1PodStatus.  # noqa: E501

        Current service state of pod. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions  # noqa: E501

        :return: The conditions of this V1PodStatus.  # noqa: E501
        :rtype: list[V1PodCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1PodStatus.

        Current service state of pod. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions  # noqa: E501

        :param conditions: The conditions of this V1PodStatus.  # noqa: E501
        :type conditions: list[V1PodCondition]
        """

        self._conditions = conditions

    @property
    def container_statuses(self):
        """Gets the container_statuses of this V1PodStatus.  # noqa: E501

        Statuses of containers in this pod. Each container in the pod should have at most one status in this list, and all statuses should be for containers in the pod. However this is not enforced. If a status for a non-existent container is present in the list, or the list has duplicate names, the behavior of various Kubernetes components is not defined and those statuses might be ignored. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status  # noqa: E501

        :return: The container_statuses of this V1PodStatus.  # noqa: E501
        :rtype: list[V1ContainerStatus]
        """
        return self._container_statuses

    @container_statuses.setter
    def container_statuses(self, container_statuses):
        """Sets the container_statuses of this V1PodStatus.

        Statuses of containers in this pod. Each container in the pod should have at most one status in this list, and all statuses should be for containers in the pod. However this is not enforced. If a status for a non-existent container is present in the list, or the list has duplicate names, the behavior of various Kubernetes components is not defined and those statuses might be ignored. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status  # noqa: E501

        :param container_statuses: The container_statuses of this V1PodStatus.  # noqa: E501
        :type container_statuses: list[V1ContainerStatus]
        """

        self._container_statuses = container_statuses

    @property
    def ephemeral_container_statuses(self):
        """Gets the ephemeral_container_statuses of this V1PodStatus.  # noqa: E501

        Statuses for any ephemeral containers that have run in this pod. Each ephemeral container in the pod should have at most one status in this list, and all statuses should be for containers in the pod. However this is not enforced. If a status for a non-existent container is present in the list, or the list has duplicate names, the behavior of various Kubernetes components is not defined and those statuses might be ignored. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status  # noqa: E501

        :return: The ephemeral_container_statuses of this V1PodStatus.  # noqa: E501
        :rtype: list[V1ContainerStatus]
        """
        return self._ephemeral_container_statuses

    @ephemeral_container_statuses.setter
    def ephemeral_container_statuses(self, ephemeral_container_statuses):
        """Sets the ephemeral_container_statuses of this V1PodStatus.

        Statuses for any ephemeral containers that have run in this pod. Each ephemeral container in the pod should have at most one status in this list, and all statuses should be for containers in the pod. However this is not enforced. If a status for a non-existent container is present in the list, or the list has duplicate names, the behavior of various Kubernetes components is not defined and those statuses might be ignored. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status  # noqa: E501

        :param ephemeral_container_statuses: The ephemeral_container_statuses of this V1PodStatus.  # noqa: E501
        :type ephemeral_container_statuses: list[V1ContainerStatus]
        """

        self._ephemeral_container_statuses = ephemeral_container_statuses

    @property
    def extended_resource_claim_status(self):
        """Gets the extended_resource_claim_status of this V1PodStatus.  # noqa: E501


        :return: The extended_resource_claim_status of this V1PodStatus.  # noqa: E501
        :rtype: V1PodExtendedResourceClaimStatus
        """
        return self._extended_resource_claim_status

    @extended_resource_claim_status.setter
    def extended_resource_claim_status(self, extended_resource_claim_status):
        """Sets the extended_resource_claim_status of this V1PodStatus.


        :param extended_resource_claim_status: The extended_resource_claim_status of this V1PodStatus.  # noqa: E501
        :type extended_resource_claim_status: V1PodExtendedResourceClaimStatus
        """

        self._extended_resource_claim_status = extended_resource_claim_status

    @property
    def host_ip(self):
        """Gets the host_ip of this V1PodStatus.  # noqa: E501

        hostIP holds the IP address of the host to which the pod is assigned. Empty if the pod has not started yet. A pod can be assigned to a node that has a problem in kubelet which in turns mean that HostIP will not be updated even if there is a node is assigned to pod  # noqa: E501

        :return: The host_ip of this V1PodStatus.  # noqa: E501
        :rtype: str
        """
        return self._host_ip

    @host_ip.setter
    def host_ip(self, host_ip):
        """Sets the host_ip of this V1PodStatus.

        hostIP holds the IP address of the host to which the pod is assigned. Empty if the pod has not started yet. A pod can be assigned to a node that has a problem in kubelet which in turns mean that HostIP will not be updated even if there is a node is assigned to pod  # noqa: E501

        :param host_ip: The host_ip of this V1PodStatus.  # noqa: E501
        :type host_ip: str
        """

        self._host_ip = host_ip

    @property
    def host_ips(self):
        """Gets the host_ips of this V1PodStatus.  # noqa: E501

        hostIPs holds the IP addresses allocated to the host. If this field is specified, the first entry must match the hostIP field. This list is empty if the pod has not started yet. A pod can be assigned to a node that has a problem in kubelet which in turns means that HostIPs will not be updated even if there is a node is assigned to this pod.  # noqa: E501

        :return: The host_ips of this V1PodStatus.  # noqa: E501
        :rtype: list[V1HostIP]
        """
        return self._host_ips

    @host_ips.setter
    def host_ips(self, host_ips):
        """Sets the host_ips of this V1PodStatus.

        hostIPs holds the IP addresses allocated to the host. If this field is specified, the first entry must match the hostIP field. This list is empty if the pod has not started yet. A pod can be assigned to a node that has a problem in kubelet which in turns means that HostIPs will not be updated even if there is a node is assigned to this pod.  # noqa: E501

        :param host_ips: The host_ips of this V1PodStatus.  # noqa: E501
        :type host_ips: list[V1HostIP]
        """

        self._host_ips = host_ips

    @property
    def init_container_statuses(self):
        """Gets the init_container_statuses of this V1PodStatus.  # noqa: E501

        Statuses of init containers in this pod. The most recent successful non-restartable init container will have ready = true, the most recently started container will have startTime set. Each init container in the pod should have at most one status in this list, and all statuses should be for containers in the pod. However this is not enforced. If a status for a non-existent container is present in the list, or the list has duplicate names, the behavior of various Kubernetes components is not defined and those statuses might be ignored. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#pod-and-container-status  # noqa: E501

        :return: The init_container_statuses of this V1PodStatus.  # noqa: E501
        :rtype: list[V1ContainerStatus]
        """
        return self._init_container_statuses

    @init_container_statuses.setter
    def init_container_statuses(self, init_container_statuses):
        """Sets the init_container_statuses of this V1PodStatus.

        Statuses of init containers in this pod. The most recent successful non-restartable init container will have ready = true, the most recently started container will have startTime set. Each init container in the pod should have at most one status in this list, and all statuses should be for containers in the pod. However this is not enforced. If a status for a non-existent container is present in the list, or the list has duplicate names, the behavior of various Kubernetes components is not defined and those statuses might be ignored. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#pod-and-container-status  # noqa: E501

        :param init_container_statuses: The init_container_statuses of this V1PodStatus.  # noqa: E501
        :type init_container_statuses: list[V1ContainerStatus]
        """

        self._init_container_statuses = init_container_statuses

    @property
    def message(self):
        """Gets the message of this V1PodStatus.  # noqa: E501

        A human readable message indicating details about why the pod is in this condition.  # noqa: E501

        :return: The message of this V1PodStatus.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this V1PodStatus.

        A human readable message indicating details about why the pod is in this condition.  # noqa: E501

        :param message: The message of this V1PodStatus.  # noqa: E501
        :type message: str
        """

        self._message = message

    @property
    def nominated_node_name(self):
        """Gets the nominated_node_name of this V1PodStatus.  # noqa: E501

        nominatedNodeName is set only when this pod preempts other pods on the node, but it cannot be scheduled right away as preemption victims receive their graceful termination periods. This field does not guarantee that the pod will be scheduled on this node. Scheduler may decide to place the pod elsewhere if other nodes become available sooner. Scheduler may also decide to give the resources on this node to a higher priority pod that is created after preemption. As a result, this field may be different than PodSpec.nodeName when the pod is scheduled.  # noqa: E501

        :return: The nominated_node_name of this V1PodStatus.  # noqa: E501
        :rtype: str
        """
        return self._nominated_node_name

    @nominated_node_name.setter
    def nominated_node_name(self, nominated_node_name):
        """Sets the nominated_node_name of this V1PodStatus.

        nominatedNodeName is set only when this pod preempts other pods on the node, but it cannot be scheduled right away as preemption victims receive their graceful termination periods. This field does not guarantee that the pod will be scheduled on this node. Scheduler may decide to place the pod elsewhere if other nodes become available sooner. Scheduler may also decide to give the resources on this node to a higher priority pod that is created after preemption. As a result, this field may be different than PodSpec.nodeName when the pod is scheduled.  # noqa: E501

        :param nominated_node_name: The nominated_node_name of this V1PodStatus.  # noqa: E501
        :type nominated_node_name: str
        """

        self._nominated_node_name = nominated_node_name

    @property
    def observed_generation(self):
        """Gets the observed_generation of this V1PodStatus.  # noqa: E501

        If set, this represents the .metadata.generation that the pod status was set based upon. This is an alpha field. Enable PodObservedGenerationTracking to be able to use this field.  # noqa: E501

        :return: The observed_generation of this V1PodStatus.  # noqa: E501
        :rtype: int
        """
        return self._observed_generation

    @observed_generation.setter
    def observed_generation(self, observed_generation):
        """Sets the observed_generation of this V1PodStatus.

        If set, this represents the .metadata.generation that the pod status was set based upon. This is an alpha field. Enable PodObservedGenerationTracking to be able to use this field.  # noqa: E501

        :param observed_generation: The observed_generation of this V1PodStatus.  # noqa: E501
        :type observed_generation: int
        """

        self._observed_generation = observed_generation

    @property
    def phase(self):
        """Gets the phase of this V1PodStatus.  # noqa: E501

        The phase of a Pod is a simple, high-level summary of where the Pod is in its lifecycle. The conditions array, the reason and message fields, and the individual container status arrays contain more detail about the pod's status. There are five possible phase values:  Pending: The pod has been accepted by the Kubernetes system, but one or more of the container images has not been created. This includes time before being scheduled as well as time spent downloading images over the network, which could take a while. Running: The pod has been bound to a node, and all of the containers have been created. At least one container is still running, or is in the process of starting or restarting. Succeeded: All containers in the pod have terminated in success, and will not be restarted. Failed: All containers in the pod have terminated, and at least one container has terminated in failure. The container either exited with non-zero status or was terminated by the system. Unknown: For some reason the state of the pod could not be obtained, typically due to an error in communicating with the host of the pod.  More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-phase  # noqa: E501

        :return: The phase of this V1PodStatus.  # noqa: E501
        :rtype: str
        """
        return self._phase

    @phase.setter
    def phase(self, phase):
        """Sets the phase of this V1PodStatus.

        The phase of a Pod is a simple, high-level summary of where the Pod is in its lifecycle. The conditions array, the reason and message fields, and the individual container status arrays contain more detail about the pod's status. There are five possible phase values:  Pending: The pod has been accepted by the Kubernetes system, but one or more of the container images has not been created. This includes time before being scheduled as well as time spent downloading images over the network, which could take a while. Running: The pod has been bound to a node, and all of the containers have been created. At least one container is still running, or is in the process of starting or restarting. Succeeded: All containers in the pod have terminated in success, and will not be restarted. Failed: All containers in the pod have terminated, and at least one container has terminated in failure. The container either exited with non-zero status or was terminated by the system. Unknown: For some reason the state of the pod could not be obtained, typically due to an error in communicating with the host of the pod.  More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-phase  # noqa: E501

        :param phase: The phase of this V1PodStatus.  # noqa: E501
        :type phase: str
        """

        self._phase = phase

    @property
    def pod_ip(self):
        """Gets the pod_ip of this V1PodStatus.  # noqa: E501

        podIP address allocated to the pod. Routable at least within the cluster. Empty if not yet allocated.  # noqa: E501

        :return: The pod_ip of this V1PodStatus.  # noqa: E501
        :rtype: str
        """
        return self._pod_ip

    @pod_ip.setter
    def pod_ip(self, pod_ip):
        """Sets the pod_ip of this V1PodStatus.

        podIP address allocated to the pod. Routable at least within the cluster. Empty if not yet allocated.  # noqa: E501

        :param pod_ip: The pod_ip of this V1PodStatus.  # noqa: E501
        :type pod_ip: str
        """

        self._pod_ip = pod_ip

    @property
    def pod_ips(self):
        """Gets the pod_ips of this V1PodStatus.  # noqa: E501

        podIPs holds the IP addresses allocated to the pod. If this field is specified, the 0th entry must match the podIP field. Pods may be allocated at most 1 value for each of IPv4 and IPv6. This list is empty if no IPs have been allocated yet.  # noqa: E501

        :return: The pod_ips of this V1PodStatus.  # noqa: E501
        :rtype: list[V1PodIP]
        """
        return self._pod_ips

    @pod_ips.setter
    def pod_ips(self, pod_ips):
        """Sets the pod_ips of this V1PodStatus.

        podIPs holds the IP addresses allocated to the pod. If this field is specified, the 0th entry must match the podIP field. Pods may be allocated at most 1 value for each of IPv4 and IPv6. This list is empty if no IPs have been allocated yet.  # noqa: E501

        :param pod_ips: The pod_ips of this V1PodStatus.  # noqa: E501
        :type pod_ips: list[V1PodIP]
        """

        self._pod_ips = pod_ips

    @property
    def qos_class(self):
        """Gets the qos_class of this V1PodStatus.  # noqa: E501

        The Quality of Service (QOS) classification assigned to the pod based on resource requirements See PodQOSClass type for available QOS classes More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-qos/#quality-of-service-classes  # noqa: E501

        :return: The qos_class of this V1PodStatus.  # noqa: E501
        :rtype: str
        """
        return self._qos_class

    @qos_class.setter
    def qos_class(self, qos_class):
        """Sets the qos_class of this V1PodStatus.

        The Quality of Service (QOS) classification assigned to the pod based on resource requirements See PodQOSClass type for available QOS classes More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-qos/#quality-of-service-classes  # noqa: E501

        :param qos_class: The qos_class of this V1PodStatus.  # noqa: E501
        :type qos_class: str
        """

        self._qos_class = qos_class

    @property
    def reason(self):
        """Gets the reason of this V1PodStatus.  # noqa: E501

        A brief CamelCase message indicating details about why the pod is in this state. e.g. 'Evicted'  # noqa: E501

        :return: The reason of this V1PodStatus.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this V1PodStatus.

        A brief CamelCase message indicating details about why the pod is in this state. e.g. 'Evicted'  # noqa: E501

        :param reason: The reason of this V1PodStatus.  # noqa: E501
        :type reason: str
        """

        self._reason = reason

    @property
    def resize(self):
        """Gets the resize of this V1PodStatus.  # noqa: E501

        Status of resources resize desired for pod's containers. It is empty if no resources resize is pending. Any changes to container resources will automatically set this to \"Proposed\" Deprecated: Resize status is moved to two pod conditions PodResizePending and PodResizeInProgress. PodResizePending will track states where the spec has been resized, but the Kubelet has not yet allocated the resources. PodResizeInProgress will track in-progress resizes, and should be present whenever allocated resources != acknowledged resources.  # noqa: E501

        :return: The resize of this V1PodStatus.  # noqa: E501
        :rtype: str
        """
        return self._resize

    @resize.setter
    def resize(self, resize):
        """Sets the resize of this V1PodStatus.

        Status of resources resize desired for pod's containers. It is empty if no resources resize is pending. Any changes to container resources will automatically set this to \"Proposed\" Deprecated: Resize status is moved to two pod conditions PodResizePending and PodResizeInProgress. PodResizePending will track states where the spec has been resized, but the Kubelet has not yet allocated the resources. PodResizeInProgress will track in-progress resizes, and should be present whenever allocated resources != acknowledged resources.  # noqa: E501

        :param resize: The resize of this V1PodStatus.  # noqa: E501
        :type resize: str
        """

        self._resize = resize

    @property
    def resource_claim_statuses(self):
        """Gets the resource_claim_statuses of this V1PodStatus.  # noqa: E501

        Status of resource claims.  # noqa: E501

        :return: The resource_claim_statuses of this V1PodStatus.  # noqa: E501
        :rtype: list[V1PodResourceClaimStatus]
        """
        return self._resource_claim_statuses

    @resource_claim_statuses.setter
    def resource_claim_statuses(self, resource_claim_statuses):
        """Sets the resource_claim_statuses of this V1PodStatus.

        Status of resource claims.  # noqa: E501

        :param resource_claim_statuses: The resource_claim_statuses of this V1PodStatus.  # noqa: E501
        :type resource_claim_statuses: list[V1PodResourceClaimStatus]
        """

        self._resource_claim_statuses = resource_claim_statuses

    @property
    def start_time(self):
        """Gets the start_time of this V1PodStatus.  # noqa: E501

        RFC 3339 date and time at which the object was acknowledged by the Kubelet. This is before the Kubelet pulled the container image(s) for the pod.  # noqa: E501

        :return: The start_time of this V1PodStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this V1PodStatus.

        RFC 3339 date and time at which the object was acknowledged by the Kubelet. This is before the Kubelet pulled the container image(s) for the pod.  # noqa: E501

        :param start_time: The start_time of this V1PodStatus.  # noqa: E501
        :type start_time: datetime
        """

        self._start_time = start_time

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1PodStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1PodStatus):
            return True

        return self.to_dict() != other.to_dict()



from typing import Any

class V1alpha1NamedRuleWithOperations:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, api_groups: list[str] | None = None, api_versions: list[str] | None = None, operations: list[str] | None = None, resource_names: list[str] | None = None, resources: list[str] | None = None, scope: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def api_groups(self) -> list[str]: ...
    @api_groups.setter
    def api_groups(self, api_groups: list[str]) -> None: ...
    @property
    def api_versions(self) -> list[str]: ...
    @api_versions.setter
    def api_versions(self, api_versions: list[str]) -> None: ...
    @property
    def operations(self) -> list[str]: ...
    @operations.setter
    def operations(self, operations: list[str]) -> None: ...
    @property
    def resource_names(self) -> list[str]: ...
    @resource_names.setter
    def resource_names(self, resource_names: list[str]) -> None: ...
    @property
    def resources(self) -> list[str]: ...
    @resources.setter
    def resources(self, resources: list[str]) -> None: ...
    @property
    def scope(self) -> str: ...
    @scope.setter
    def scope(self, scope: str) -> None: ...



from kubernetes_asyncio.client.api_client import ApiClient
from kubernetes_asyncio.client.models import V1APIResourceList
from kubernetes_asyncio.client.models import V1RuntimeClass
from kubernetes_asyncio.client.models import V1RuntimeClassList
from kubernetes_asyncio.client.models import V1Status
from multidict import CIMultiDictProxy
from typing import Any
from typing import Awaitable

class NodeV1Api:
    def __init__(self, api_client: ApiClient | None = None) -> None: ...
    def create_runtime_class(self, body: V1RuntimeClass, **kwargs: Any) -> Awaitable[V1RuntimeClass]: ...
    def create_runtime_class_with_http_info(self, body: V1RuntimeClass, **kwargs: Any) -> Awaitable[tuple[V1RuntimeClass, int, CIMultiDictProxy]]: ...
    def delete_collection_runtime_class(self, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_collection_runtime_class_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def delete_runtime_class(self, name: str, **kwargs: Any) -> Awaitable[V1Status]: ...
    def delete_runtime_class_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1Status, int, CIMultiDictProxy]]: ...
    def get_api_resources(self, **kwargs: Any) -> Awaitable[V1APIResourceList]: ...
    def get_api_resources_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1APIResourceList, int, CIMultiDictProxy]]: ...
    def list_runtime_class(self, **kwargs: Any) -> Awaitable[V1RuntimeClassList]: ...
    def list_runtime_class_with_http_info(self, **kwargs: Any) -> Awaitable[tuple[V1RuntimeClassList, int, CIMultiDictProxy]]: ...
    def patch_runtime_class(self, name: str, body: Any, **kwargs: Any) -> Awaitable[V1RuntimeClass]: ...
    def patch_runtime_class_with_http_info(self, name: str, body: Any, **kwargs: Any) -> Awaitable[tuple[V1RuntimeClass, int, CIMultiDictProxy]]: ...
    def read_runtime_class(self, name: str, **kwargs: Any) -> Awaitable[V1RuntimeClass]: ...
    def read_runtime_class_with_http_info(self, name: str, **kwargs: Any) -> Awaitable[tuple[V1RuntimeClass, int, CIMultiDictProxy]]: ...
    def replace_runtime_class(self, name: str, body: V1RuntimeClass, **kwargs: Any) -> Awaitable[V1RuntimeClass]: ...
    def replace_runtime_class_with_http_info(self, name: str, body: V1RuntimeClass, **kwargs: Any) -> Awaitable[tuple[V1RuntimeClass, int, CIMultiDictProxy]]: ...



from kubernetes_asyncio.client.models import V1NodeSelector
from kubernetes_asyncio.client.models import V1PreferredSchedulingTerm
from typing import Any

class V1NodeAffinity:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, preferred_during_scheduling_ignored_during_execution: list[V1PreferredSchedulingTerm] | None = None, required_during_scheduling_ignored_during_execution: V1NodeSelector | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def preferred_during_scheduling_ignored_during_execution(self) -> list[V1PreferredSchedulingTerm]: ...
    @preferred_during_scheduling_ignored_during_execution.setter
    def preferred_during_scheduling_ignored_during_execution(self, preferred_during_scheduling_ignored_during_execution: list[V1PreferredSchedulingTerm]) -> None: ...
    @property
    def required_during_scheduling_ignored_during_execution(self) -> V1NodeSelector: ...
    @required_during_scheduling_ignored_during_execution.setter
    def required_during_scheduling_ignored_during_execution(self, required_during_scheduling_ignored_during_execution: V1NodeSelector) -> None: ...



from kubernetes_asyncio.client.models import V1CustomResourceSubresourceScale
from typing import Any

class V1CustomResourceSubresources:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, scale: V1CustomResourceSubresourceScale | None = None, status: Any | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def scale(self) -> V1CustomResourceSubresourceScale: ...
    @scale.setter
    def scale(self, scale: V1CustomResourceSubresourceScale) -> None: ...
    @property
    def status(self) -> Any: ...
    @status.setter
    def status(self, status: Any) -> None: ...



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.34.3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes_asyncio.client.configuration import Configuration


class V1alpha1Mutation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'apply_configuration': 'V1alpha1ApplyConfiguration',
        'json_patch': 'V1alpha1JSONPatch',
        'patch_type': 'str'
    }

    attribute_map = {
        'apply_configuration': 'applyConfiguration',
        'json_patch': 'jsonPatch',
        'patch_type': 'patchType'
    }

    def __init__(self, apply_configuration=None, json_patch=None, patch_type=None, local_vars_configuration=None):  # noqa: E501
        """V1alpha1Mutation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default()
        self.local_vars_configuration = local_vars_configuration

        self._apply_configuration = None
        self._json_patch = None
        self._patch_type = None
        self.discriminator = None

        if apply_configuration is not None:
            self.apply_configuration = apply_configuration
        if json_patch is not None:
            self.json_patch = json_patch
        self.patch_type = patch_type

    @property
    def apply_configuration(self):
        """Gets the apply_configuration of this V1alpha1Mutation.  # noqa: E501


        :return: The apply_configuration of this V1alpha1Mutation.  # noqa: E501
        :rtype: V1alpha1ApplyConfiguration
        """
        return self._apply_configuration

    @apply_configuration.setter
    def apply_configuration(self, apply_configuration):
        """Sets the apply_configuration of this V1alpha1Mutation.


        :param apply_configuration: The apply_configuration of this V1alpha1Mutation.  # noqa: E501
        :type apply_configuration: V1alpha1ApplyConfiguration
        """

        self._apply_configuration = apply_configuration

    @property
    def json_patch(self):
        """Gets the json_patch of this V1alpha1Mutation.  # noqa: E501


        :return: The json_patch of this V1alpha1Mutation.  # noqa: E501
        :rtype: V1alpha1JSONPatch
        """
        return self._json_patch

    @json_patch.setter
    def json_patch(self, json_patch):
        """Sets the json_patch of this V1alpha1Mutation.


        :param json_patch: The json_patch of this V1alpha1Mutation.  # noqa: E501
        :type json_patch: V1alpha1JSONPatch
        """

        self._json_patch = json_patch

    @property
    def patch_type(self):
        """Gets the patch_type of this V1alpha1Mutation.  # noqa: E501

        patchType indicates the patch strategy used. Allowed values are \"ApplyConfiguration\" and \"JSONPatch\". Required.  # noqa: E501

        :return: The patch_type of this V1alpha1Mutation.  # noqa: E501
        :rtype: str
        """
        return self._patch_type

    @patch_type.setter
    def patch_type(self, patch_type):
        """Sets the patch_type of this V1alpha1Mutation.

        patchType indicates the patch strategy used. Allowed values are \"ApplyConfiguration\" and \"JSONPatch\". Required.  # noqa: E501

        :param patch_type: The patch_type of this V1alpha1Mutation.  # noqa: E501
        :type patch_type: str
        """
        if self.local_vars_configuration.client_side_validation and patch_type is None:  # noqa: E501
            raise ValueError("Invalid value for `patch_type`, must not be `None`")  # noqa: E501

        self._patch_type = patch_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1alpha1Mutation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1alpha1Mutation):
            return True

        return self.to_dict() != other.to_dict()



from kubernetes_asyncio.client.models import V1beta1MatchCondition
from kubernetes_asyncio.client.models import V1beta1MatchResources
from kubernetes_asyncio.client.models import V1beta1Mutation
from kubernetes_asyncio.client.models import V1beta1ParamKind
from kubernetes_asyncio.client.models import V1beta1Variable
from typing import Any

class V1beta1MutatingAdmissionPolicySpec:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, failure_policy: str | None = None, match_conditions: list[V1beta1MatchCondition] | None = None, match_constraints: V1beta1MatchResources | None = None, mutations: list[V1beta1Mutation] | None = None, param_kind: V1beta1ParamKind | None = None, reinvocation_policy: str | None = None, variables: list[V1beta1Variable] | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def failure_policy(self) -> str: ...
    @failure_policy.setter
    def failure_policy(self, failure_policy: str) -> None: ...
    @property
    def match_conditions(self) -> list[V1beta1MatchCondition]: ...
    @match_conditions.setter
    def match_conditions(self, match_conditions: list[V1beta1MatchCondition]) -> None: ...
    @property
    def match_constraints(self) -> V1beta1MatchResources: ...
    @match_constraints.setter
    def match_constraints(self, match_constraints: V1beta1MatchResources) -> None: ...
    @property
    def mutations(self) -> list[V1beta1Mutation]: ...
    @mutations.setter
    def mutations(self, mutations: list[V1beta1Mutation]) -> None: ...
    @property
    def param_kind(self) -> V1beta1ParamKind: ...
    @param_kind.setter
    def param_kind(self, param_kind: V1beta1ParamKind) -> None: ...
    @property
    def reinvocation_policy(self) -> str: ...
    @reinvocation_policy.setter
    def reinvocation_policy(self, reinvocation_policy: str) -> None: ...
    @property
    def variables(self) -> list[V1beta1Variable]: ...
    @variables.setter
    def variables(self, variables: list[V1beta1Variable]) -> None: ...



# Copyright 2018 The Kubernetes Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json
import sys
from unittest import IsolatedAsyncioTestCase
from unittest.mock import ANY, AsyncMock, patch

from kubernetes_asyncio.config.config_exception import ConfigException
from kubernetes_asyncio.config.exec_provider import ExecProvider
from kubernetes_asyncio.config.kube_config import ConfigNode


class ExecProviderTest(IsolatedAsyncioTestCase):
    def setUp(self) -> None:
        self.input_ok = ConfigNode(
            "test",
            {
                "command": "aws-iam-authenticator",
                "args": ["token", "-i", "dummy"],
                "apiVersion": "client.authentication.k8s.io/v1beta1",
                "env": None,
            },
        )
        self.output_ok = """
        {
            "apiVersion": "client.authentication.k8s.io/v1beta1",
            "kind": "ExecCredential",
            "status": {
                "token": "dummy"
            }
        }
        """

        process_patch = patch(
            "kubernetes_asyncio.config.exec_provider.asyncio.create_subprocess_exec"
        )
        self.exec_mock = process_patch.start()
        self.process_mock = self.exec_mock.return_value
        self.process_mock.stdout.read = AsyncMock(return_value=self.output_ok)
        self.process_mock.stderr.read = AsyncMock(return_value="")
        self.process_mock.wait = AsyncMock(return_value=0)

    def tearDown(self) -> None:
        patch.stopall()

    def test_missing_input_keys(self) -> None:
        exec_configs = [{}, {"command": ""}, {"apiVersion": ""}]
        for exec_config in exec_configs:
            with self.assertRaises(ConfigException) as context:
                ExecProvider(ConfigNode("dummy-1", exec_config))
            self.assertIn(
                "exec: malformed request. missing key", context.exception.args[0]
            )

    async def test_error_code_returned(self) -> None:
        self.process_mock.stdout.read.return_value = ""
        self.process_mock.wait.return_value = 1
        with self.assertRaisesRegex(ConfigException, "exec: process returned 1"):
            ep = ExecProvider(self.input_ok)
            await ep.run()

    async def test_nonjson_output_returned(self) -> None:
        self.process_mock.stdout.read.return_value = ""
        with self.assertRaisesRegex(
            ConfigException, "exec: failed to decode process output"
        ):
            ep = ExecProvider(self.input_ok)
            await ep.run()

    async def test_missing_output_keys(self) -> None:
        outputs = [
            """
            {
                "kind": "ExecCredential",
                "status": {
                    "token": "dummy"
                }
            }
            """,
            """
            {
                "apiVersion": "client.authentication.k8s.io/v1beta1",
                "status": {
                    "token": "dummy"
                }
            }
            """,
            """
            {
                "apiVersion": "client.authentication.k8s.io/v1beta1",
                "kind": "ExecCredential"
            }
            """,
        ]
        for output in outputs:
            self.process_mock.stdout.read.return_value = output
            with self.assertRaisesRegex(
                ConfigException, "exec: malformed response. missing key"
            ):
                ep = ExecProvider(self.input_ok)
                await ep.run()

    async def test_mismatched_api_version(self) -> None:
        wrong_api_version = "client.authentication.k8s.io/v1"
        output = (
            """
        {
            "apiVersion": "%s",
            "kind": "ExecCredential",
            "status": {
                "token": "dummy"
            }
        }
        """
            % wrong_api_version
        )
        self.process_mock.stdout.read.return_value = output
        with self.assertRaisesRegex(
            ConfigException,
            "exec: plugin api version {} does not match".format(wrong_api_version),
        ):
            ep = ExecProvider(self.input_ok)
            await ep.run()

    async def test_ok_01(self) -> None:
        ep = ExecProvider(self.input_ok)
        result = await ep.run()
        self.assertTrue(isinstance(result, dict))
        self.assertTrue("token" in result)
        self.exec_mock.assert_called_once_with(
            "aws-iam-authenticator",
            "token",
            "-i",
            "dummy",
            env=ANY,
            stderr=-1,
            stdin=None,
            stdout=-1,
        )
        self.process_mock.stdout.read.assert_awaited_once()
        self.process_mock.stderr.read.assert_awaited_once()
        self.process_mock.wait.assert_awaited_once()

    async def test_ok_with_args(self) -> None:
        input_ok = ConfigNode(
            "test",
            {
                "command": "aws-iam-authenticator",
                "apiVersion": "client.authentication.k8s.io/v1beta1",
                "args": ["token", "-i", "dummy", "--mock", "90"],
            },
        )
        ep = ExecProvider(input_ok)
        result = await ep.run()
        self.assertTrue(isinstance(result, dict))
        self.assertTrue("token" in result)
        self.exec_mock.assert_called_once_with(
            "aws-iam-authenticator",
            "token",
            "-i",
            "dummy",
            "--mock",
            "90",
            env=ANY,
            stderr=-1,
            stdin=None,
            stdout=-1,
        )
        self.process_mock.stdout.read.assert_awaited_once()
        self.process_mock.stderr.read.assert_awaited_once()
        self.process_mock.wait.assert_awaited_once()

    async def test_ok_with_env(self) -> None:
        input_ok = ConfigNode(
            "test",
            {
                "command": "aws-iam-authenticator",
                "apiVersion": "client.authentication.k8s.io/v1beta1",
                "args": ["token", "-i", "dummy"],
                "env": [
                    {
                        "name": "EXEC_PROVIDER_ENV_NAME",
                        "value": "EXEC_PROVIDER_ENV_VALUE",
                    }
                ],
            },
        )

        ep = ExecProvider(input_ok)
        result = await ep.run()
        self.assertTrue(isinstance(result, dict))
        self.assertTrue("token" in result)

        env_used = self.exec_mock.await_args_list[0][1]["env"]
        self.assertEqual(env_used["EXEC_PROVIDER_ENV_NAME"], "EXEC_PROVIDER_ENV_VALUE")
        self.assertEqual(
            json.loads(env_used["KUBERNETES_EXEC_INFO"]),
            {
                "apiVersion": "client.authentication.k8s.io/v1beta1",
                "kind": "ExecCredential",
                "spec": {"interactive": sys.stdout.isatty()},
            },
        )
        self.exec_mock.assert_called_once_with(
            "aws-iam-authenticator",
            "token",
            "-i",
            "dummy",
            env=ANY,
            stderr=-1,
            stdin=None,
            stdout=-1,
        )
        self.process_mock.stdout.read.assert_awaited_once()
        self.process_mock.stderr.read.assert_awaited_once()
        self.process_mock.wait.assert_awaited_once()



from typing import Any

class V1GCEPersistentDiskVolumeSource:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, fs_type: str | None = None, partition: int | None = None, pd_name: str | None = None, read_only: bool | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def fs_type(self) -> str: ...
    @fs_type.setter
    def fs_type(self, fs_type: str) -> None: ...
    @property
    def partition(self) -> int: ...
    @partition.setter
    def partition(self, partition: int) -> None: ...
    @property
    def pd_name(self) -> str: ...
    @pd_name.setter
    def pd_name(self, pd_name: str) -> None: ...
    @property
    def read_only(self) -> bool: ...
    @read_only.setter
    def read_only(self, read_only: bool) -> None: ...



from kubernetes_asyncio.client.models import V1beta2DeviceSubRequest
from kubernetes_asyncio.client.models import V1beta2ExactDeviceRequest
from typing import Any

class V1beta2DeviceRequest:
    def __eq__(self, other: Any) -> bool: ...
    def __init__(self, exactly: V1beta2ExactDeviceRequest | None = None, first_available: list[V1beta2DeviceSubRequest] | None = None, name: str | None = None, local_vars_configuration: Any | None = None) -> None: ...
    def __ne__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    def to_dict(self, serialize: bool = False) -> dict[str, Any]: ...
    def to_str(self) -> str: ...
    @property
    def exactly(self) -> V1beta2ExactDeviceRequest: ...
    @exactly.setter
    def exactly(self, exactly: V1beta2ExactDeviceRequest) -> None: ...
    @property
    def first_available(self) -> list[V1beta2DeviceSubRequest]: ...
    @first_available.setter
    def first_available(self, first_available: list[V1beta2DeviceSubRequest]) -> None: ...
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, name: str) -> None: ...
